@@ -964,3 +964,8 @@ class Connection:
                         backup_info,))
 
             time.sleep(poll_interval)
+
+    def get_api_info(self):
+        response = self.do_get_request(self.sesamapi_base_url, allowable_response_status_codes=[200])
+        info = response.json()
+        return info
